@@ -8,8 +8,8 @@
 ##' @export
 
 roxbc <- function(name){ # roxygenize, build and check a package
-    require(roxygen)
-    roxygenize(name)
+    require(roxygen2)
+    roxygenize(name,roxygen.dir=paste(name,".roxygen",sep=""))
     out <- system(paste("R CMD build --compact-vignettes=gs ",name,".roxygen",sep=""),intern=TRUE)
     stuff <- out[length(out)]
     if (length(grep("building",stuff))==0){
